@@ -77,6 +77,7 @@ struct BrowseMainPagePrivate : public Ui_BrowseMainPage
     KSelectAction* mSortAction;
     QActionGroup* mThumbnailDetailsActionGroup;
     PreviewItemDelegate* mDelegate;
+    QPalette mNormalPalette;
 
     void setupWidgets()
     {
@@ -94,11 +95,13 @@ struct BrowseMainPagePrivate : public Ui_BrowseMainPage
         // can't be used directly from Designer)
         mFilePlacesModel = new KFilePlacesModel(q);
         mUrlNavigator = new KUrlNavigator(mFilePlacesModel, KUrl(), mUrlNavigatorContainer);
+        mUrlNavigatorContainer->setAutoFillBackground(true);
         QVBoxLayout* layout = new QVBoxLayout(mUrlNavigatorContainer);
         layout->setMargin(0);
         layout->addWidget(mUrlNavigator);
         QObject::connect(mUrlNavigator, SIGNAL(urlsDropped(KUrl, QDropEvent*)),
                          q, SLOT(slotUrlsDropped(KUrl, QDropEvent*)));
+        updateUrlNavigatorBackgroundColor();
 
         // Thumbnail slider
         QObject::connect(mThumbnailSlider, SIGNAL(valueChanged(int)),
@@ -163,6 +166,20 @@ struct BrowseMainPagePrivate : public Ui_BrowseMainPage
         mAddFilterButton->setMenu(menu);
     }
 
+    void setupFullScreenToolBar()
+    {
+        mFullScreenToolBar->setIconDimensions(KIconLoader::SizeMedium);
+        mFullScreenToolBar->setToolButtonStyle(Qt::ToolButtonIconOnly);
+        #define addAction(name) mFullScreenToolBar->addAction(mActionCollection->action(name))
+        addAction("browse");
+        addAction("view");
+        #undef addAction
+
+        mFullScreenToolBar2->setIconDimensions(KIconLoader::SizeMedium);
+        mFullScreenToolBar2->setToolButtonStyle(Qt::ToolButtonIconOnly);
+        mFullScreenToolBar2->addAction(mActionCollection->action("leave_fullscreen"));
+    }
+
     void updateDocumentCountLabel()
     {
         QString text = i18ncp("@label", "%1 document", "%1 documents", mDocumentCount);
@@ -193,6 +210,13 @@ struct BrowseMainPagePrivate : public Ui_BrowseMainPage
         }
         return count;
     }
+
+    void updateUrlNavigatorBackgroundColor()
+    {
+       QPalette pal(q->palette());
+       pal.setColor(QPalette::Window, pal.color(QPalette::Window).dark(110));
+       mUrlNavigatorContainer->setPalette(pal);
+    }
 };
 
 BrowseMainPage::BrowseMainPage(QWidget* parent, SortedDirModel* dirModel, KActionCollection* actionCollection)
@@ -328,9 +352,31 @@ void BrowseMainPage::updateThumbnailDetails()
     d->mDelegate->setThumbnailDetails(details);
 }
 
-void BrowseMainPage::applyPalette(const QPalette& palette)
+void BrowseMainPage::setFullScreenMode(bool fullScreen)
 {
-    d->mThumbnailView->setPalette(palette);
+    // For fullscreen mode, we use the application palette, which has been set to a fullscreen version
+    setPalette(fullScreen ? QPalette() : d->mNormalPalette);
+    d->updateUrlNavigatorBackgroundColor();
+    d->mUrlNavigatorContainer->setContentsMargins(
+        fullScreen ? 6 : 0,
+        0, 0, 0);
+    PreviewItemDelegate::ContextBarActions actions = PreviewItemDelegate::SelectionAction | PreviewItemDelegate::RotateAction;
+    if (!fullScreen) {
+        actions |= PreviewItemDelegate::FullScreenAction;
+    }
+    d->mDelegate->setContextBarActions(actions);
+
+    d->mFullScreenToolBar->setVisible(fullScreen);
+    d->mFullScreenToolBar2->setVisible(fullScreen);
+    if (fullScreen && d->mFullScreenToolBar->actions().isEmpty()) {
+        d->setupFullScreenToolBar();
+    }
+}
+
+void BrowseMainPage::setNormalPalette(const QPalette& palette)
+{
+    d->mNormalPalette = palette;
+    setPalette(d->mNormalPalette);
 }
 
 void BrowseMainPage::slotUrlsDropped(const KUrl& destUrl, QDropEvent* event)
