@@ -42,6 +42,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <KEditToolBar>
 #include <KFileDialog>
 #include <KFileItem>
+#include <KGlobalSettings>
 #include <KMenuBar>
 #include <KLocale>
 #include <KMessageBox>
@@ -90,7 +91,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <lib/archiveutils.h>
 #include <lib/document/documentfactory.h>
 #include <lib/eventwatcher.h>
-#include <lib/fullscreenbar.h>
 #include <lib/gwenviewconfig.h>
 #include <lib/mimetypeutils.h>
 #include <lib/print/printhelper.h>
@@ -132,11 +132,29 @@ enum MainPageId {
 
 struct MainWindowState
 {
-    MainPageId mMainPageId;
     bool mToolBarVisible;
     Qt::WindowStates mWindowState;
 };
 
+/*
+
+Layout of the main window looks like this:
+
+.-mCentralSplitter-----------------------------.
+|.-mSideBar--. .-mContentWidget---------------.|
+||           | |.-mSaveBar-------------------.||
+||           | ||                            |||
+||           | |'----------------------------'||
+||           | |.-mViewStackedWidget---------.||
+||           | ||                            |||
+||           | ||                            |||
+||           | ||                            |||
+||           | ||                            |||
+||           | |'----------------------------'||
+|'-----------' '------------------------------'|
+'----------------------------------------------'
+
+*/
 struct MainWindow::Private
 {
     GvCore* mGvCore;
@@ -152,8 +170,8 @@ struct MainWindow::Private
     StartMainPage* mStartMainPage;
     SideBar* mSideBar;
     QStackedWidget* mViewStackedWidget;
-    FullScreenBar* mFullScreenBar;
     FullScreenContent* mFullScreenContent;
+    QPalette mFullScreenPalette;
     SaveBar* mSaveBar;
     bool mStartSlideShowWhenDirListerCompleted;
     SlideShow* mSlideShow;
@@ -181,7 +199,6 @@ struct MainWindow::Private
     SortedDirModel* mDirModel;
     ContextManager* mContextManager;
 
-    bool mDistractionFreeMode;
     MainWindowState mStateBeforeFullScreen;
 
     KUrl mUrlToSelect;
@@ -195,6 +212,20 @@ struct MainWindow::Private
 
     void setupWidgets()
     {
+        // FIXME: Can we rely on ObsidianCoast to always be there?
+        {
+            KSharedConfigPtr config;
+            QString name = GwenviewConfig::fullScreenColorScheme();
+            if (name.contains('/')) {
+                config = KSharedConfig::openConfig(name);
+            } else {
+                config = KSharedConfig::openConfig(QString("color-schemes/%1.colors").arg(name), KConfig::FullConfig, "data");
+            }
+            mFullScreenPalette = KGlobalSettings::createApplicationPalette(config);
+        }
+
+        mFullScreenContent = new FullScreenContent(q);
+
         mCentralSplitter = new Splitter(Qt::Horizontal, q);
         q->setCentralWidget(mCentralSplitter);
 
@@ -244,10 +275,6 @@ struct MainWindow::Private
 
         mThumbnailView = mBrowseMainPage->thumbnailView();
         mUrlNavigator = mBrowseMainPage->urlNavigator();
-        QPalette pal = mUrlNavigator->palette();
-        pal.setColor(QPalette::Window, pal.color(QPalette::Window).dark(110));
-        mUrlNavigator->setAutoFillBackground(true);
-        mUrlNavigator->setPalette(pal);
 
         mDocumentInfoProvider = new DocumentInfoProvider(mDirModel);
         mThumbnailView->setDocumentInfoProvider(mDocumentInfoProvider);
@@ -323,12 +350,16 @@ struct MainWindow::Private
         action->setShortcut(Qt::Key_F5);
 
         mBrowseAction = view->addAction("browse");
-        mBrowseAction->setText(i18nc("@action Switch to file list", "Browse"));
+        mBrowseAction->setText(i18nc("@action:intoolbar Switch to file list", "Browse"));
+        mBrowseAction->setToolTip(i18nc("@info:tooltip", "Browse folders for images"));
         mBrowseAction->setCheckable(true);
         mBrowseAction->setIcon(KIcon("view-list-icons"));
+        connect(mViewMainPage, SIGNAL(goToBrowseModeRequested()),
+            mBrowseAction, SLOT(trigger()));
 
         mViewAction = view->addAction("view");
-        mViewAction->setText(i18nc("@action Switch to image view", "View"));
+        mViewAction->setText(i18nc("@action:intoolbar Switch to image view", "View"));
+        mViewAction->setToolTip(i18nc("@info:tooltip", "View selected images"));
         mViewAction->setIcon(KIcon("view-preview"));
         mViewAction->setCheckable(true);
 
@@ -340,38 +371,42 @@ struct MainWindow::Private
                 q, SLOT(setActiveViewModeAction(QAction*)));
 
         mFullScreenAction = static_cast<KToggleFullScreenAction*>(view->addAction(KStandardAction::FullScreen, q, SLOT(toggleFullScreen(bool))));
-        connect(mViewMainPage, SIGNAL(toggleFullScreenRequested()),
-                mFullScreenAction, SLOT(trigger()));
+        KShortcut shortcut = mFullScreenAction->shortcut();
+        if (shortcut.alternate().isEmpty()) {
+            shortcut.setAlternate(Qt::Key_F11);
+        }
+        mFullScreenAction->setShortcut(shortcut);
 
-        KAction* reduceLodAction = view->addAction("reduce_lod", q, SLOT(reduceLevelOfDetails()));
-        // FIXME Find a better text for this action
-        reduceLodAction->setText(i18nc("@action Go back to a more general page (start page <- list <- image)", "Back"));
-        reduceLodAction->setShortcut(Qt::Key_Escape);
+        KAction* leaveFullScreenAction = view->addAction("leave_fullscreen", q, SLOT(leaveFullScreen()));
+        leaveFullScreenAction->setIcon(KIcon("view-restore"));
+        leaveFullScreenAction->setPriority(QAction::LowPriority);
+        leaveFullScreenAction->setText(i18nc("@action", "Leave Fullscreen Mode"));
+        leaveFullScreenAction->setShortcut(Qt::Key_Escape);
 
         mGoToPreviousAction = view->addAction("go_previous", q, SLOT(goToPrevious()));
         mGoToPreviousAction->setPriority(QAction::LowPriority);
         mGoToPreviousAction->setIcon(KIcon("media-skip-backward"));
         mGoToPreviousAction->setText(i18nc("@action Go to previous image", "Previous"));
-        mGoToPreviousAction->setToolTip(i18n("Go to Previous Image"));
+        mGoToPreviousAction->setToolTip(i18nc("@info:tooltip", "Go to previous image"));
         mGoToPreviousAction->setShortcut(Qt::Key_Backspace);
 
         mGoToNextAction = view->addAction("go_next", q, SLOT(goToNext()));
         mGoToNextAction->setPriority(QAction::LowPriority);
         mGoToNextAction->setIcon(KIcon("media-skip-forward"));
         mGoToNextAction->setText(i18nc("@action Go to next image", "Next"));
-        mGoToNextAction->setToolTip(i18n("Go to Next Image"));
+        mGoToNextAction->setToolTip(i18nc("@info:tooltip", "Go to next image"));
         mGoToNextAction->setShortcut(Qt::Key_Space);
 
         mGoToFirstAction = view->addAction("go_first", q, SLOT(goToFirst()));
         mGoToFirstAction->setPriority(QAction::LowPriority);
         mGoToFirstAction->setText(i18nc("@action Go to first image", "First"));
-        mGoToFirstAction->setToolTip(i18n("Go to First Image"));
+        mGoToFirstAction->setToolTip(i18nc("@info:tooltip", "Go to first image"));
         mGoToFirstAction->setShortcut(Qt::Key_Home);
 
         mGoToLastAction = view->addAction("go_last", q, SLOT(goToLast()));
         mGoToLastAction->setPriority(QAction::LowPriority);
         mGoToLastAction->setText(i18nc("@action Go to last image", "Last"));
-        mGoToLastAction->setToolTip(i18n("Go to Last Image"));
+        mGoToLastAction->setToolTip(i18nc("@info:tooltip", "Go to last image"));
         mGoToLastAction->setShortcut(Qt::Key_End);
 
         mGoUpAction = view->addAction(KStandardAction::Up, q, SLOT(goUp()));
@@ -380,12 +415,13 @@ struct MainWindow::Private
         action->setPriority(QAction::LowPriority);
         action->setIcon(KIcon("go-home"));
         action->setText(i18nc("@action", "Start Page"));
+        action->setToolTip(i18nc("@info:tooltip", "Open the start page"));
 
         mToggleSideBarAction = view->add<KToggleAction>("toggle_sidebar");
         connect(mToggleSideBarAction, SIGNAL(toggled(bool)),
                 q, SLOT(toggleSideBar(bool)));
         mToggleSideBarAction->setIcon(KIcon("view-sidetree"));
-        mToggleSideBarAction->setShortcut(Qt::Key_F11);
+        mToggleSideBarAction->setShortcut(Qt::Key_F4);
         mToggleSideBarAction->setText(i18nc("@action", "Sidebar"));
         connect(mBrowseMainPage->toggleSideBarButton(), SIGNAL(clicked()),
                 mToggleSideBarAction, SLOT(trigger()));
@@ -598,12 +634,9 @@ struct MainWindow::Private
         }
     }
 
-    void setupFullScreenBar()
+    void setupFullScreenContent()
     {
-        mFullScreenBar = new FullScreenBar(mViewMainPage);
-        mFullScreenContent = new FullScreenContent(
-            mFullScreenBar, q->actionCollection(), mSlideShow);
-
+        mFullScreenContent->init(q->actionCollection(), mViewMainPage, mSlideShow);
         ThumbnailBarView* view = mFullScreenContent->thumbnailBar();
         view->setModel(mDirModel);
         view->setDocumentInfoProvider(mDocumentInfoProvider);
@@ -634,12 +667,6 @@ struct MainWindow::Private
         setActionEnabled("add_folder_to_places", enabled);
     }
 
-    void updateDistractionsState()
-    {
-        const bool isFullScreen = mFullScreenAction->isChecked();
-        mFullScreenBar->setActivated(!mDistractionFreeMode && isFullScreen);
-    }
-
     void updateActions()
     {
         bool isRasterImage = false;
@@ -799,7 +826,6 @@ MainWindow::MainWindow()
 {
     d->q = this;
     d->mCurrentMainPageId = StartMainPageId;
-    d->mDistractionFreeMode = false;
     d->mDirModel = new SortedDirModel(this);
     d->mGvCore = new GvCore(this, d->mDirModel);
     d->mPreloader = new Preloader(this);
@@ -809,7 +835,7 @@ MainWindow::MainWindow()
     d->setupActions();
     d->setupUndoActions();
     d->setupContextManager();
-    d->setupFullScreenBar();
+    d->setupFullScreenContent();
     d->updateActions();
     updatePreviousNextActions();
     d->mSaveBar->initActionDependentWidgets();
@@ -1113,7 +1139,7 @@ void MainWindow::updateToggleSideBarAction()
     } else {
         text = QString::fromUtf8(visible ? "▮←" : "▮→");
     }
-    QString toolTip = visible ? i18n("Hide Sidebar") : i18n("Show Sidebar");
+    QString toolTip = visible ? i18nc("@info:tooltip", "Hide sidebar") : i18nc("@info:tooltip", "Show sidebar");
 
     QList<QToolButton*> lst;
     lst << d->mBrowseMainPage->toggleSideBarButton()
@@ -1251,14 +1277,10 @@ void MainWindow::updatePreviousNextActions()
     d->mGoToLastAction->setEnabled(d->mGoToNextAction->isEnabled());
 }
 
-void MainWindow::reduceLevelOfDetails()
+void MainWindow::leaveFullScreen()
 {
     if (d->mFullScreenAction->isChecked()) {
         d->mFullScreenAction->trigger();
-    } else if (d->mCurrentMainPageId == ViewMainPageId) {
-        d->mBrowseAction->trigger();
-    } else {
-        showStartMainPage();
     }
 }
 
@@ -1273,19 +1295,19 @@ void MainWindow::toggleFullScreen(bool checked)
         resetAutoSaveSettings();
 
         // Save state
-        d->mStateBeforeFullScreen.mMainPageId = d->mCurrentMainPageId;
         d->mStateBeforeFullScreen.mToolBarVisible = toolBar()->isVisible();
         d->mStateBeforeFullScreen.mWindowState = windowState();
 
         // Go full screen
-        d->mViewAction->trigger();
-
         setWindowState(windowState() | Qt::WindowFullScreen);
         menuBar()->hide();
         toolBar()->hide();
+
+        QApplication::setPalette(d->mFullScreenPalette);
+        d->mFullScreenContent->setFullScreenMode(true);
+        d->mBrowseMainPage->setFullScreenMode(true);
         d->mViewMainPage->setFullScreenMode(true);
         d->mSaveBar->setFullScreenMode(true);
-        d->updateDistractionsState();
         d->setScreenSaverEnabled(false);
 
         // HACK: Only load sidebar config now, because it looks at
@@ -1296,11 +1318,9 @@ void MainWindow::toggleFullScreen(bool checked)
         setAutoSaveSettings();
 
         // Back to normal
-        d->mCurrentMainPageId = d->mStateBeforeFullScreen.mMainPageId;
-        if (d->mCurrentMainPageId == BrowseMainPageId) {
-            d->mBrowseAction->trigger();
-        }
-
+        QApplication::setPalette(KGlobalSettings::createApplicationPalette());
+        d->mFullScreenContent->setFullScreenMode(false);
+        d->mBrowseMainPage->setFullScreenMode(false);
         d->mViewMainPage->setFullScreenMode(false);
         d->mSlideShow->stop();
         d->mSaveBar->setFullScreenMode(false);
@@ -1308,7 +1328,6 @@ void MainWindow::toggleFullScreen(bool checked)
         menuBar()->setVisible(d->mShowMenuBarAction->isChecked());
         toolBar()->setVisible(d->mStateBeforeFullScreen.mToolBarVisible);
 
-        d->updateDistractionsState();
         d->setScreenSaverEnabled(true);
 
         // Keep this after mViewMainPage->setFullScreenMode(false).
@@ -1487,8 +1506,8 @@ void MainWindow::loadConfig()
     pal.setColor(QPalette::Text, fgColor);
 
     // Apply to widgets
-    d->mBrowseMainPage->applyPalette(pal);
     d->mStartMainPage->applyPalette(pal);
+    d->mBrowseMainPage->setNormalPalette(pal);
     d->mViewMainPage->setNormalPalette(pal);
 }
 
@@ -1573,8 +1592,7 @@ void MainWindow::resizeEvent(QResizeEvent* event)
 
 void MainWindow::setDistractionFreeMode(bool value)
 {
-    d->mDistractionFreeMode = value;
-    d->updateDistractionsState();
+    d->mFullScreenContent->setDistractionFreeMode(value);
 }
 
 void MainWindow::saveProperties(KConfigGroup& group)
