@@ -20,6 +20,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include "viewmainpage.moc"
 
 // Qt
+#include <QApplication>
 #include <QCheckBox>
 #include <QItemSelectionModel>
 #include <QLabel>
@@ -150,7 +151,6 @@ struct ViewMainPagePrivate
 
     bool mFullScreenMode;
     QPalette mNormalPalette;
-    QPalette mFullScreenPalette;
     bool mCompareMode;
     bool mThumbnailBarVisibleBeforeFullScreen;
 
@@ -312,12 +312,6 @@ struct ViewMainPagePrivate
         layout->addWidget(mThumbnailSplitter);
     }
 
-    void applyPalette()
-    {
-        QPalette palette = mFullScreenMode ? mFullScreenPalette : mNormalPalette;
-        mDocumentViewContainer->setPalette(palette);
-    }
-
     void saveSplitterConfig()
     {
         if (mThumbnailBar->isVisible()) {
@@ -375,13 +369,10 @@ ViewMainPage::ViewMainPage(QWidget* parent, SlideShow* slideShow, KActionCollect
     d->mFullScreenMode = false;
     d->mCompareMode = false;
     d->mThumbnailBarVisibleBeforeFullScreen = false;
-    d->mFullScreenPalette = QPalette(palette());
-    d->mFullScreenPalette.setColor(QPalette::Base, Qt::black);
-    d->mFullScreenPalette.setColor(QPalette::Text, Qt::white);
 
-    QShortcut* toggleFullScreenShortcut = new QShortcut(this);
-    toggleFullScreenShortcut->setKey(Qt::Key_Return);
-    connect(toggleFullScreenShortcut, SIGNAL(activated()), SIGNAL(toggleFullScreenRequested()));
+    QShortcut* goToBrowseModeShortcut = new QShortcut(this);
+    goToBrowseModeShortcut->setKey(Qt::Key_Return);
+    connect(goToBrowseModeShortcut, SIGNAL(activated()), SIGNAL(goToBrowseModeRequested()));
 
     d->setupToolContainer();
     d->setupStatusBar();
@@ -475,14 +466,20 @@ void ViewMainPage::setFullScreenMode(bool fullScreenMode)
 {
     d->mFullScreenMode = fullScreenMode;
     d->mStatusBarContainer->setVisible(!fullScreenMode);
-    d->applyPalette();
+
     if (fullScreenMode) {
         d->mThumbnailBarVisibleBeforeFullScreen = d->mToggleThumbnailBarAction->isChecked();
         if (d->mThumbnailBarVisibleBeforeFullScreen) {
             d->mToggleThumbnailBarAction->trigger();
         }
-    } else if (d->mThumbnailBarVisibleBeforeFullScreen) {
-        d->mToggleThumbnailBarAction->trigger();
+        QPalette pal = QApplication::palette();
+        pal.setColor(QPalette::Base, Qt::black);
+        d->mDocumentViewContainer->setPalette(pal);
+    } else {
+        if (d->mThumbnailBarVisibleBeforeFullScreen) {
+            d->mToggleThumbnailBarAction->trigger();
+        }
+        d->mDocumentViewContainer->setPalette(d->mNormalPalette);
     }
     d->mToggleThumbnailBarAction->setEnabled(!fullScreenMode);
 }
@@ -560,7 +557,10 @@ Document::Ptr ViewMainPage::currentDocument() const
 
 bool ViewMainPage::isEmpty() const
 {
-    return !currentDocument();
+    if (!d->currentView()) {
+        return true;
+    }
+    return d->currentView()->isEmpty();
 }
 
 RasterImageView* ViewMainPage::imageView() const
@@ -579,7 +579,7 @@ DocumentView* ViewMainPage::documentView() const
 void ViewMainPage::setNormalPalette(const QPalette& palette)
 {
     d->mNormalPalette = palette;
-    d->applyPalette();
+    d->mDocumentViewContainer->setPalette(palette);
     d->setupThumbnailBarStyleSheet();
 }
 
