@@ -164,8 +164,8 @@ struct DocumentViewPrivate
 
     void setupHud()
     {
-        GraphicsHudButton* trashButton = createHudButton(i18n("Trash"), "user-trash", false);
-        GraphicsHudButton* deselectButton = createHudButton(i18n("Deselect"), "list-remove", true);
+        GraphicsHudButton* trashButton = createHudButton(i18nc("@info:tooltip", "Trash"), "user-trash", false);
+        GraphicsHudButton* deselectButton = createHudButton(i18nc("@action:button", "Deselect"), "list-remove", true);
 
         QGraphicsWidget* content = new QGraphicsWidget;
         QGraphicsLinearLayout* layout = new QGraphicsLinearLayout(content);
@@ -409,6 +409,11 @@ void DocumentView::finishOpenUrl()
     d->updateCaption();
 }
 
+bool DocumentView::isEmpty() const
+{
+    return qobject_cast<EmptyAdapter*>(d->mAdapter.data());
+}
+
 void DocumentView::loadAdapterConfig()
 {
     d->mAdapter->loadConfig();
