@@ -130,7 +130,7 @@ struct PreviewItemDelegatePrivate
     QModelIndex mIndexUnderCursor;
     int mThumbnailSize;
     PreviewItemDelegate::ThumbnailDetails mDetails;
-    PreviewItemDelegate::ContextBarMode mContextBarMode;
+    PreviewItemDelegate::ContextBarActions mContextBarActions;
     Qt::TextElideMode mTextElideMode;
 
     QPointer<ToolTipWidget> mToolTip;
@@ -151,15 +151,14 @@ struct PreviewItemDelegatePrivate
 
     void showContextBar(const QRect& rect, const QPixmap& thumbnailPix)
     {
-        if (mContextBarMode == PreviewItemDelegate::NoContextBar) {
+        if (mContextBarActions == PreviewItemDelegate::NoAction) {
             return;
         }
         mContextBar->adjustSize();
-        // Center bar in FullContextBar mode, left align in
-        // SelectionOnlyContextBar mode
-        const int posX = mContextBarMode == PreviewItemDelegate::FullContextBar
-                         ? (rect.width() - mContextBar->width()) / 2
-                         : 0;
+        // Center bar, except if only showing SelectionAction.
+        const int posX = mContextBarActions == PreviewItemDelegate::SelectionAction
+            ? 0
+            : (rect.width() - mContextBar->width()) / 2;
         const int posY = qMax(CONTEXTBAR_MARGIN, mThumbnailSize - thumbnailPix.height() - mContextBar->height());
         mContextBar->move(rect.topLeft() + QPoint(posX, posY));
         mContextBar->show();
@@ -550,16 +549,16 @@ struct PreviewItemDelegatePrivate
 
     void updateContextBar()
     {
-        if (mContextBarMode == PreviewItemDelegate::NoContextBar) {
+        if (mContextBarActions == PreviewItemDelegate::NoAction) {
             mContextBar->hide();
             return;
         }
         const int width = itemWidth();
         const int buttonWidth = mRotateRightButton->sizeHint().width();
-        bool full = mContextBarMode == PreviewItemDelegate::FullContextBar;
-        mFullScreenButton->setVisible(full);
-        mRotateLeftButton->setVisible(full && width >= 3 * buttonWidth);
-        mRotateRightButton->setVisible(full && width >= 4 * buttonWidth);
+        mFullScreenButton->setVisible(mContextBarActions & PreviewItemDelegate::FullScreenAction);
+        bool rotate = mContextBarActions & PreviewItemDelegate::RotateAction;
+        mRotateLeftButton->setVisible(rotate && width >= 3 * buttonWidth);
+        mRotateRightButton->setVisible(rotate && width >= 4 * buttonWidth);
         mContextBar->adjustSize();
     }
 
@@ -578,7 +577,7 @@ PreviewItemDelegate::PreviewItemDelegate(ThumbnailView* view)
     view->viewport()->installEventFilter(this);
     d->mThumbnailSize = view->thumbnailSize();
     d->mDetails = FileNameDetail;
-    d->mContextBarMode = FullContextBar;
+    d->mContextBarActions = SelectionAction | FullScreenAction | RotateAction;
     d->mTextElideMode = Qt::ElideRight;
 
     connect(view, SIGNAL(rowsRemovedSignal(QModelIndex, int, int)),
@@ -859,14 +858,14 @@ void PreviewItemDelegate::setThumbnailDetails(PreviewItemDelegate::ThumbnailDeta
     d->mView->scheduleDelayedItemsLayout();
 }
 
-PreviewItemDelegate::ContextBarMode PreviewItemDelegate::contextBarMode() const
+PreviewItemDelegate::ContextBarActions PreviewItemDelegate::contextBarActions() const
 {
-    return d->mContextBarMode;
+    return d->mContextBarActions;
 }
 
-void PreviewItemDelegate::setContextBarMode(PreviewItemDelegate::ContextBarMode mode)
+void PreviewItemDelegate::setContextBarActions(PreviewItemDelegate::ContextBarActions actions)
 {
-    d->mContextBarMode = mode;
+    d->mContextBarActions = actions;
     d->updateContextBar();
 }
 
